@@ -2,10 +2,20 @@
 List of all the action, filter and context names used across Lekt. This module is used
 to generate part of the reference documentation.
 """
-# The Lekt plugin system is licensed under the terms of the Apache 2.0 license.
+from __future__ import annotations
+
+# The Tutor plugin system is licensed under the terms of the Apache 2.0 license.
 __license__ = "Apache 2.0"
 
+from typing import Any, Callable
+
+import click
+
+from lekt.types import Config
+
 from . import actions, contexts, filters
+from .actions import Action, ActionTemplate
+from .filters import Filter, FilterTemplate
 
 __all__ = ["Actions", "Filters", "Contexts"]
 
@@ -28,9 +38,11 @@ class Actions:
     #: Triggered whenever a "docker-compose start", "up" or "restart" command is executed.
     #:
     #: :parameter: str root: project root.
-    #: :parameter: dict[str, ...] config: project configuration.
+    #: :parameter: dict config: project configuration.
     #: :parameter: str name: docker-compose project name.
-    COMPOSE_PROJECT_STARTED = actions.get("compose:project:started")
+    COMPOSE_PROJECT_STARTED: Action[[str, Config, str]] = actions.get(
+        "compose:project:started"
+    )
 
     #: Called whenever the core project is ready to run. This action is called as soon
     #: as possible. This is the right time to discover plugins, for instance. In
@@ -45,12 +57,12 @@ class Actions:
     #: developers probably don't have to implement this action themselves.
     #:
     #: This action does not have any parameter.
-    CORE_READY = actions.get("core:ready")
+    CORE_READY: Action[[]] = actions.get("core:ready")
 
     #: Called as soon as we have access to the Lekt project root.
     #:
     #: :parameter str root: absolute path to the project root.
-    PROJECT_ROOT_READY = actions.get("project:root:ready")
+    PROJECT_ROOT_READY: Action[str] = actions.get("project:root:ready")
 
     #: Triggered when a single plugin needs to be loaded. Only plugins that have previously been
     #: discovered can be loaded (see :py:data:`CORE_READY`).
@@ -63,13 +75,13 @@ class Actions:
     #: they want to perform a specific action at the moment the plugin is enabled.
     #:
     #: This action does not have any parameter.
-    PLUGIN_LOADED = actions.get_template("plugins:loaded:{0}")
+    PLUGIN_LOADED: ActionTemplate[[]] = actions.get_template("plugins:loaded:{0}")
 
     #: Triggered after all plugins have been loaded. At this point the list of loaded
     #: plugins may be obtained from the :py:data:``Filters.PLUGINS_LOADED`` filter.
     #:
     #: This action does not have any parameter.
-    PLUGINS_LOADED = actions.get("plugins:loaded")
+    PLUGINS_LOADED: Action[[]] = actions.get("plugins:loaded")
 
     #: Triggered when a single plugin is unloaded. Only plugins that have previously been
     #: loaded can be unloaded (see :py:data:`PLUGIN_LOADED`).
@@ -81,8 +93,8 @@ class Actions:
     #:
     #: :parameter str plugin: plugin name.
     #: :parameter str root: absolute path to the project root.
-    #: :parameter dict config: full project configuration
-    PLUGIN_UNLOADED = actions.get("plugins:unloaded")
+    #: :parameter config: full project configuration
+    PLUGIN_UNLOADED: Action[str, str, Config] = actions.get("plugins:unloaded")
 
 
 class Filters:
@@ -113,19 +125,23 @@ class Filters:
     #:     - ``path`` is a tuple that corresponds to a template relative path.
     #:       Example: ``("myplugin", "hooks", "myservice", "pre-init")`` (see:py:data:`IMAGES_BUILD`).
     #:       The command to execute will be read from that template, after it is rendered.
-    COMMANDS_INIT = filters.get("commands:init")
+    COMMANDS_INIT: Filter[list[tuple[str, tuple[str, ...]]], str] = filters.get(
+        "commands:init"
+    )
 
     #: List of commands to be executed prior to initialization. These commands are run even
     #: before the mysql databases are created and the migrations are applied.
     #:
     #: :parameter list[tuple[str, tuple[str, ...]]] tasks: list of ``(service, path)`` tasks. (see :py:data:`COMMANDS_INIT`).
-    COMMANDS_PRE_INIT = filters.get("commands:pre-init")
+    COMMANDS_PRE_INIT: Filter[list[tuple[str, tuple[str, ...]]], []] = filters.get(
+        "commands:pre-init"
+    )
 
     #: Same as :py:data:`COMPOSE_LOCAL_TMP` but for the development environment.
-    COMPOSE_DEV_TMP = filters.get("compose:dev:tmp")
+    COMPOSE_DEV_TMP: Filter[Config, []] = filters.get("compose:dev:tmp")
 
     #: Same as :py:data:`COMPOSE_LOCAL_JOBS_TMP` but for the development environment.
-    COMPOSE_DEV_JOBS_TMP = filters.get("compose:dev-jobs:tmp")
+    COMPOSE_DEV_JOBS_TMP: Filter[Config, []] = filters.get("compose:dev-jobs:tmp")
 
     #: List of folders to bind-mount in docker-compose containers, either in ``lekt local`` or ``lekt dev``.
     #:
@@ -146,7 +162,7 @@ class Filters:
     #: :parameter str name: basename of the host-mounted folder. In the example above,
     #:   this is "edx-platform". When implementing this filter you should check this name to
     #:   conditionnally add mounts.
-    COMPOSE_MOUNTS = filters.get("compose:mounts")
+    COMPOSE_MOUNTS: Filter[list[tuple[str, str]], [str]] = filters.get("compose:mounts")
 
     #: Contents of the (local|dev)/docker-compose.tmp.yml files that will be generated at
     #: runtime. This is used for instance to bind-mount folders from the host (see
@@ -154,10 +170,10 @@ class Filters:
     #:
     #: :parameter dict[str, ...] docker_compose_tmp: values which will be serialized to local/docker-compose.tmp.yml.
     #:   Keys and values will be rendered before saving, such that you may include ``{{ ... }}`` statements.
-    COMPOSE_LOCAL_TMP = filters.get("compose:local:tmp")
+    COMPOSE_LOCAL_TMP: Filter[Config, []] = filters.get("compose:local:tmp")
 
     #: Same as :py:data:`COMPOSE_LOCAL_TMP` but for jobs
-    COMPOSE_LOCAL_JOBS_TMP = filters.get("compose:local-jobs:tmp")
+    COMPOSE_LOCAL_JOBS_TMP: Filter[Config, []] = filters.get("compose:local-jobs:tmp")
 
     #: List of images to be built when we run ``lekt images build ...``.
     #:
@@ -171,8 +187,10 @@ class Filters:
     #:      rendered at runtime with the user configuration. Thus, the image tag could
     #:      be ``"{{ DOCKER_REGISTRY }}/myimage:{{ LEKT_VERSION }}"``.
     #:    - ``args`` is a list of arguments that will be passed to ``docker build ...``.
-    #: :parameter dict config: user configuration.
-    IMAGES_BUILD = filters.get("images:build")
+    #: :parameter Config config: user configuration.
+    IMAGES_BUILD: Filter[
+        list[tuple[str, tuple[str, ...], str, tuple[str, ...]]], [Config]
+    ] = filters.get("images:build")
 
     #: List of images to be pulled when we run ``lekt images pull ...``.
     #:
@@ -180,18 +198,18 @@ class Filters:
     #:
     #:    - ``name`` is the name of the image, as in ``lekt images pull myimage``.
     #:    - ``tag`` is the Docker tag that will be applied to the image. (see :py:data:`IMAGES_BUILD`).
-    #: :parameter dict config: user configuration.
-    IMAGES_PULL = filters.get("images:pull")
+    #: :parameter Config config: user configuration.
+    IMAGES_PULL: Filter[list[tuple[str, str]], [Config]] = filters.get("images:pull")
 
     #: List of images to be pushed when we run ``lekt images push ...``.
     #: Parameters are the same as for :py:data:`IMAGES_PULL`.
-    IMAGES_PUSH = filters.get("images:push")
+    IMAGES_PUSH: Filter[list[tuple[str, str]], [Config]] = filters.get("images:push")
 
     #: List of command line interface (CLI) commands.
     #:
     #: :parameter list commands: commands are instances of ``click.Command``. They will
-    #:   all be added as subcommands of the main ``lekt`` command.
-    CLI_COMMANDS = filters.get("cli:commands")
+    #:   all be added as subcommands of the main ``tutor`` command.
+    CLI_COMMANDS: Filter[list[click.Command], []] = filters.get("cli:commands")
 
     #: Declare new default configuration settings that don't necessarily have to be saved in the user
     #: ``config.yml`` file. Default settings may be overridden with ``lekt config save --set=...``, in which
@@ -199,21 +217,23 @@ class Filters:
     #:
     #: :parameter list[tuple[str, ...]] items: list of (name, value) new settings. All
     #:    new entries must be prefixed with the plugin name in all-caps.
-    CONFIG_DEFAULTS = filters.get("config:defaults")
+    CONFIG_DEFAULTS: Filter[list[tuple[str, Any]], []] = filters.get("config:defaults")
 
     #: Modify existing settings, either from Lekt core or from other plugins. Beware not to override any
     #: important setting, such as passwords! Overridden setting values will be printed to stdout when the plugin
     #: is disabled, such that users have a chance to back them up.
     #:
     #: :parameter list[tuple[str, ...]] items: list of (name, value) settings.
-    CONFIG_OVERRIDES = filters.get("config:overrides")
+    CONFIG_OVERRIDES: Filter[list[tuple[str, Any]], []] = filters.get(
+        "config:overrides"
+    )
 
     #: Declare uniqaue configuration settings that must be saved in the user ``config.yml`` file. This is where
     #: you should declare passwords and randomly-generated values that are different from one environment to the next.
     #:
     #: :parameter list[tuple[str, ...]] items: list of (name, value) new settings. All
     #:   names must be prefixed with the plugin name in all-caps.
-    CONFIG_UNIQUE = filters.get("config:unique")
+    CONFIG_UNIQUE: Filter[list[tuple[str, Any]], []] = filters.get("config:unique")
 
     #: List of patches that should be inserted in a given location of the templates. The
     #: filter name must be formatted with the patch name.
@@ -221,13 +241,13 @@ class Filters:
     #: prefer :py:data:`ENV_PATCHES`.
     #:
     #: :parameter list[str] patches: each item is the unrendered patch content.
-    ENV_PATCH = filters.get_template("env:patches:{0}")
+    ENV_PATCH: FilterTemplate[list[str], []] = filters.get_template("env:patches:{0}")
 
     #: List of patches that should be inserted in a given location of the templates. This is very similar to :py:data:`ENV_PATCH`, except that the patch is added as a ``(name, content)`` tuple.
     #:
     #: :parameter list[tuple[str, str]] patches: pairs of (name, content) tuples. Use this
-    #:   filter to modify the Lekt templates.
-    ENV_PATCHES = filters.get("env:patches")
+    #:   filter to modify the Tutor templates.
+    ENV_PATCHES: Filter[list[tuple[str, str]], []] = filters.get("env:patches")
 
     #: List of template path patterns to be ignored when rendering templates to the project root. By default, we ignore:
     #:
@@ -238,20 +258,20 @@ class Filters:
     #: Ignored patterns are overridden by include patterns; see :py:data:`ENV_PATTERNS_INCLUDE`.
     #:
     #: :parameter list[str] patterns: list of regular expression patterns. E.g: ``r"(.*/)?ignored_file_name(/.*)?"``.
-    ENV_PATTERNS_IGNORE = filters.get("env:patterns:ignore")
+    ENV_PATTERNS_IGNORE: Filter[list[str], []] = filters.get("env:patterns:ignore")
 
     #: List of template path patterns to be included when rendering templates to the project root.
     #: Patterns from this list will take priority over the patterns from :py:data:`ENV_PATTERNS_IGNORE`.
     #:
     #: :parameter list[str] patterns: list of regular expression patterns. See :py:data:`ENV_PATTERNS_IGNORE`.
-    ENV_PATTERNS_INCLUDE = filters.get("env:patterns:include")
+    ENV_PATTERNS_INCLUDE: Filter[list[str], []] = filters.get("env:patterns:include")
 
     #: List of all template root folders.
     #:
     #: :parameter list[str] templates_root: absolute paths to folders which contain templates.
     #:   The templates in these folders will then be accessible by the environment
     #:   renderer using paths that are relative to their template root.
-    ENV_TEMPLATE_ROOTS = filters.get("env:templates:roots")
+    ENV_TEMPLATE_ROOTS: Filter[list[str], []] = filters.get("env:templates:roots")
 
     #: List of template source/destination targets.
     #:
@@ -260,7 +280,9 @@ class Filters:
     #:   is a path relative to the environment root. For instance: adding ``("c/d",
     #:   "a/b")`` to the filter will cause all files from "c/d" to be rendered to the ``a/b/c/d``
     #:   subfolder.
-    ENV_TEMPLATE_TARGETS = filters.get("env:templates:targets")
+    ENV_TEMPLATE_TARGETS: Filter[list[tuple[str, str]], []] = filters.get(
+        "env:templates:targets"
+    )
 
     #: List of `Jinja2 filters <https://jinja.palletsprojects.com/en/latest/templates/#filters>`__ that will be
     #: available in templates. Jinja2 filters are basically functions that can be used
@@ -291,12 +313,16 @@ class Filters:
     #:
     #: :parameter filters: list of (name, function) tuples. The function signature
     #:   should correspond to its usage in templates.
-    ENV_TEMPLATE_FILTERS = filters.get("env:templates:filters")
+    ENV_TEMPLATE_FILTERS: Filter[
+        list[tuple[str, Callable[..., Any]]], []
+    ] = filters.get("env:templates:filters")
 
     #: List of extra variables to be included in all templates.
     #:
     #: :parameter filters: list of (name, value) tuples.
-    ENV_TEMPLATE_VARIABLES = filters.get("env:templates:variables")
+    ENV_TEMPLATE_VARIABLES: Filter[list[tuple[str, Any]], []] = filters.get(
+        "env:templates:variables"
+    )
 
     #: List of installed plugins. In order to be added to this list, a plugin must first
     #: be discovered (see :py:data:`Actions.CORE_READY`).
@@ -304,19 +330,21 @@ class Filters:
     #: :param list[str] plugins: plugin developers probably don't have to implement this
     #:   filter themselves, but they can apply it to check for the presence of other
     #:   plugins.
-    PLUGINS_INSTALLED = filters.get("plugins:installed")
+    PLUGINS_INSTALLED: Filter[list[str], []] = filters.get("plugins:installed")
 
     #: Information about each installed plugin, including its version.
     #: Keep this information to a single line for easier parsing by 3rd-party scripts.
     #:
     #: :param list[tuple[str, str]] versions: each pair is a ``(plugin, info)`` tuple.
-    PLUGINS_INFO = filters.get("plugins:installed:versions")
+    PLUGINS_INFO: Filter[list[tuple[str, str]], []] = filters.get(
+        "plugins:installed:versions"
+    )
 
     #: List of loaded plugins.
     #:
     #: :param list[str] plugins: plugin developers probably don't have to modify this
     #:   filter themselves, but they can apply it to check whether other plugins are enabled.
-    PLUGINS_LOADED = filters.get("plugins:loaded")
+    PLUGINS_LOADED: Filter[list[str], []] = filters.get("plugins:loaded")
 
 
 class Contexts:
@@ -348,8 +376,8 @@ class Contexts:
             # do stuff and all created hooks will include MY_CONTEXT
 
         # Apply only the hook callbacks that were created within MY_CONTEXT
-        hooks.Actions.MY_ACTION.do(context=str(hooks.Contexts.MY_CONTEXT))
-        hooks.Filters.MY_FILTER.apply(context=hooks.Contexts.MY_CONTEXT.name)
+        hooks.Actions.MY_ACTION.do_from_context(str(hooks.Contexts.MY_CONTEXT))
+        hooks.Filters.MY_FILTER.apply_from_context(hooks.Contexts.MY_CONTEXT.name)
     """
 
     #: We enter this context whenever we create hooks for a specific application or :
